@@ -2,5 +2,6 @@ from flask_modals.modal import (
     Modal,
     render_template_modal,
     render_template_redirect,
-    redirect_to
+    redirect_to,
+    response
 )
